@@ -11,4 +11,4 @@ PLUGINS = ()
 # Default settings for jeeves.core.plugins.ShortenerPlugin
 SHORTENER_BACKEND = 'google'
 SHORTENER_LOGIN = None
-SHORTENER_API = None
\ No newline at end of file
+SHORTENER_API_KEY = None
